package org.rcisoft.business.memFeedBack.controller;
/*固定导入*/
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.media.Schema;
import io.swagger.v3.oas.annotations.Parameters;
import io.swagger.v3.oas.annotations.Operation;
import org.rcisoft.business.memFeedBack.entity.MemFeedback;
import org.rcisoft.business.memFeedBack.service.MemFeedbackService;
import org.rcisoft.core.anno.CyOpeLogAnno;
import org.rcisoft.core.operlog.enums.CyLogTypeEnum;
import org.rcisoft.core.util.CyEpExcelUtil;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.validation.BindingResult;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import org.rcisoft.core.result.CyResult;
import org.rcisoft.core.util.CyResultGenUtil;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.constant.CyMessCons;
import org.rcisoft.core.controller.CyPaginationController;
import org.rcisoft.core.util.CyUserUtil;
import org.rcisoft.core.model.CyGridModel;
import org.rcisoft.core.exception.CyServiceException;
import jakarta.servlet.http.HttpServletResponse;
import javax.validation.Valid;



import java.util.List;

/**
* Created by cy on 2025年2月24日 下午5:16:32.
*/
@RestController
@RequestMapping("/memfeedback")
public class MemFeedbackController extends CyPaginationController<MemFeedback> {


    @Autowired
    private MemFeedbackService memFeedbackServiceImpl;

    @PreAuthorize("@cyPerm.hasPerm('mem:feedback:add')")
    @CyOpeLogAnno(title = "system-意见反馈管理-新增意见反馈", businessType = CyLogTypeEnum.INSERT)
    @Operation(summary="添加意见反馈", description="添加意见反馈")
    @PostMapping(value = "/add")
    public CyResult add(@Valid MemFeedback memFeedback, BindingResult bindingResult) {
        CyPersistModel data = memFeedbackServiceImpl.persist(memFeedback);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        memFeedback);
    }

    @PreAuthorize("@cyPerm.hasPerm('mem:feedback:delete')")
    @CyOpeLogAnno(title = "system-意见反馈管理-删除意见反馈", businessType = CyLogTypeEnum.DELETE)
    @Operation(summary="逻辑删除意见反馈", description="逻辑删除意见反馈")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @DeleteMapping("/deleteLogical/{businessId:\\w+}")
    public CyResult deleteLogical(@PathVariable int businessId,MemFeedback memFeedback) {
        memFeedback.setBusinessId(businessId);
        CyPersistModel data = memFeedbackServiceImpl.removeLogical(memFeedback);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('mem:feedback:delete')")
    @CyOpeLogAnno(title = "system-意见反馈管理-删除意见反馈", businessType = CyLogTypeEnum.DELETE)
    @Operation(summary="删除意见反馈", description="删除意见反馈")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @DeleteMapping("/delete/{businessId:\\w+}")
    public CyResult delete(@PathVariable int businessId,MemFeedback memFeedback) {
        memFeedback.setBusinessId(businessId);
        CyPersistModel data = memFeedbackServiceImpl.remove(memFeedback);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        businessId);
    }

    @PreAuthorize("@cyPerm.hasPerm('mem:feedback:update')")
    @CyOpeLogAnno(title = "system-意见反馈管理-修改意见反馈", businessType = CyLogTypeEnum.UPDATE)
    @Operation(summary="修改意见反馈", description="修改意见反馈")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = false,  schema = @Schema(type = "string"))})
    @PutMapping("/update/{businessId:\\w+}")
    public CyResult update(@PathVariable int businessId, @Valid MemFeedback memFeedback, BindingResult bindingResult) {
        memFeedback.setBusinessId(businessId);
        CyPersistModel data = memFeedbackServiceImpl.merge(memFeedback);
        return CyResultGenUtil.builder(data,
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        memFeedback);
    }

    @PreAuthorize("@cyPerm.hasPerm('mem:feedback:detail')")
    @CyOpeLogAnno(title = "system-意见反馈管理-查询意见反馈", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询单一意见反馈", description="查询单一意见反馈")
    @Parameters({@Parameter(name = "businessId", description = "businessId", required = true,  schema = @Schema(type = "string"))})
    @GetMapping("/detail/{businessId:\\w+}")
    public CyResult detail(@PathVariable int businessId) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
        memFeedbackServiceImpl.findById(businessId));
    }

    @PreAuthorize("@cyPerm.hasPerm('mem:feedback:list')")
    @CyOpeLogAnno(title = "system-意见反馈管理-查询意见反馈", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="查询意见反馈集合", description="查询意见反馈集合")
    @GetMapping(value = "/listAll")
    public CyResult listAll(MemFeedback memFeedback) {
        return CyResultGenUtil.builder(new CyPersistModel(1),
            CyMessCons.MESSAGE_ALERT_SUCCESS,
            CyMessCons.MESSAGE_ALERT_ERROR,
            memFeedbackServiceImpl.findAll(memFeedback));
    }

    @PreAuthorize("@cyPerm.hasPerm('mem:feedback:list')")
    @CyOpeLogAnno(title = "system-意见反馈管理-查询意见反馈", businessType = CyLogTypeEnum.QUERY)
    @Operation(summary="分页查询意见反馈集合", description="分页查询意见反馈集合")
    @GetMapping(value = "/list")
    public CyGridModel listByPagination(MemFeedback memFeedback) {
        memFeedbackServiceImpl.findAllByPagination(getPaginationUtility(), memFeedback);
        return getGridModelResponse();
    }

    @CyOpeLogAnno(title = "system-意见反馈管理-查询意见反馈", businessType = CyLogTypeEnum.EXPORT)
    @Operation(summary = "导出意见反馈信息", description = "导出意见反馈信息")
    @GetMapping(value = "/export")
    public void outMemFeedback(HttpServletResponse response,MemFeedback memFeedback,@PathVariable @RequestParam(defaultValue = "0") String excelId) {
        String excelName="";
        switch(excelId){
            case "0": excelName="意见反馈信息.xls";break;
            case "1": excelName="意见反馈信息.xlsx";break;
            case "2": excelName="意见反馈信息.csv";break;
        }
        List<MemFeedback> memFeedbackList = memFeedbackServiceImpl.export(memFeedback);
        CyEpExcelUtil.exportExcel(memFeedbackList, "意见反馈信息", "意见反馈信息", MemFeedback.class, excelName, response);
    }
}
