package org.rcisoft.business.memFeedBack.service.impl;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import lombok.extern.slf4j.Slf4j;
import org.rcisoft.business.memFeedBack.dao.MemFeedbackRepository;
import org.rcisoft.business.memFeedBack.entity.MemFeedback;
import org.rcisoft.business.memFeedBack.service.MemFeedbackService;
import org.rcisoft.core.model.CyPageInfo;
import org.rcisoft.core.model.CyPersistModel;
import org.rcisoft.core.util.CyUserUtil;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Isolation;
import org.springframework.transaction.annotation.Propagation;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * Created by cy on 2025年2月24日 下午5:16:32.
 */
@Service
@Transactional(readOnly = true,propagation = Propagation.NOT_SUPPORTED)
@Slf4j
public class MemFeedbackServiceImpl extends ServiceImpl<MemFeedbackRepository, MemFeedback> implements MemFeedbackService {


    /**
    * 保存 意见反馈
    * @param memFeedback
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel persist(MemFeedback memFeedback){
        //增加操作
        memFeedback.setStatus("0");
        int line = baseMapper.insert(memFeedback);
        log.debug(CyUserUtil.getAuthenUsername()+"新增了ID为"+
            memFeedback.getBusinessId()+"的意见反馈信息");
        return new CyPersistModel(line);
    }

    /**
    * 删除 意见反馈
    * @param memFeedback
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel remove(MemFeedback memFeedback){
        int line = baseMapper.realDelete(memFeedback);
        log.debug(CyUserUtil.getAuthenUsername()+"删除了ID为"+
            memFeedback.getBusinessId()+"的意见反馈信息");
        return new CyPersistModel(line);
    }

    /**
    * 逻辑删除 意见反馈
    * @param memFeedback
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel removeLogical(MemFeedback memFeedback){
        memFeedback.setDeleted();
        int line = baseMapper.deleteById(memFeedback);
            log.debug(CyUserUtil.getAuthenUsername()+"逻辑删除了ID为"+
                memFeedback.getBusinessId()+"的意见反馈信息");
            return new CyPersistModel(line);
    }

    /**
    * 修改 意见反馈
    * @param memFeedback
    * @return
    */
    @Transactional(propagation = Propagation.REQUIRED,isolation = Isolation.DEFAULT)
    @Override
    public CyPersistModel merge(MemFeedback memFeedback){
        int line = baseMapper.updateById(memFeedback);
        log.debug(CyUserUtil.getAuthenUsername()+"修改了ID为"+ memFeedback.getBusinessId()+"的意见反馈信息");
        return new CyPersistModel(line);
    }

    /**
    * 根据id查询 意见反馈
    * @param id
    * @return
    */
    @Override
    public MemFeedback findById(int id){
        return baseMapper.selectById(id);
    }

    /**
    * 分页查询 意见反馈
    * @param memFeedback
    * @return
    */
    @Override
    public IPage<MemFeedback> findAllByPagination(CyPageInfo<MemFeedback> paginationUtility,
                                                  MemFeedback memFeedback){
        return baseMapper.queryMemFeedbacksPaged(paginationUtility,memFeedback);

    }

    /**
    * 查询list 意见反馈
    * @param memFeedback
    * @return
    */
    @Override
    public List<MemFeedback> findAll(MemFeedback memFeedback){
        return baseMapper.queryMemFeedbacks(memFeedback);

    }

    /**
    * 导出意见反馈
    * @return
    */
    @Override
    public List<MemFeedback> export(MemFeedback memFeedback) {
        List<MemFeedback> memFeedbackList = baseMapper.queryMemFeedbacks(memFeedback);
        return memFeedbackList;
    }

}
